package betterquesting.questing.party;

import betterquesting.api.enums.EnumPartyStatus;
import betterquesting.api.questing.party.IParty;
import betterquesting.api2.storage.INBTPartial;
import betterquesting.core.BetterQuesting;
import betterquesting.network.handlers.NetInviteSync;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.UUID;
import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import net.minecraft.entity.player.EntityPlayerMP;
import net.minecraft.nbt.NBTBase;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.nbt.NBTTagList;
import net.minecraft.server.MinecraftServer;

/* loaded from: betterquesting_questing_party.jar:betterquesting/questing/party/PartyInvitations.class */
public class PartyInvitations implements INBTPartial<NBTTagList, UUID> {
    public static final PartyInvitations INSTANCE = new PartyInvitations();
    private final HashMap<UUID, HashMap<Integer, Long>> invites = new HashMap<>();

    public /* bridge */ /* synthetic */ NBTBase writeToNBT(NBTBase nBTBase, @Nullable List list) {
        return writeToNBT((NBTTagList) nBTBase, (List<UUID>) list);
    }

    public synchronized void postInvite(@Nonnull UUID uuid, int id, long expiryTime) {
        if (expiryTime <= 0) {
            BetterQuesting.logger.error("Received an invite that has already expired!");
            return;
        }
        IParty party = (IParty) PartyManager.INSTANCE.getValue(id);
        if (party == null || party.getStatus(uuid) != null) {
            return;
        }
        HashMap<Integer, Long> list = this.invites.computeIfAbsent(uuid, key -> {
            return new HashMap();
        });
        list.put(Integer.valueOf(id), Long.valueOf(System.currentTimeMillis() + expiryTime));
    }

    public synchronized boolean acceptInvite(@Nonnull UUID uuid, int id) {
        HashMap<Integer, Long> userInvites = this.invites.get(uuid);
        if (userInvites == null || userInvites.size() <= 0) {
            return false;
        }
        long timestamp = userInvites.get(Integer.valueOf(id)).longValue();
        IParty party = (IParty) PartyManager.INSTANCE.getValue(id);
        boolean valid = timestamp > System.currentTimeMillis();
        if (valid && party != null) {
            party.setStatus(uuid, EnumPartyStatus.MEMBER);
        }
        userInvites.remove(Integer.valueOf(id));
        if (userInvites.size() <= 0) {
            this.invites.remove(uuid);
        }
        return valid;
    }

    public synchronized void revokeInvites(@Nonnull UUID uuid, int... ids) {
        HashMap<Integer, Long> userInvites = this.invites.get(uuid);
        if (userInvites == null || userInvites.size() <= 0) {
            return;
        }
        for (int i : ids) {
            userInvites.remove(Integer.valueOf(i));
        }
        if (userInvites.size() <= 0) {
            this.invites.remove(uuid);
        }
    }

    public synchronized List<Map.Entry<Integer, Long>> getPartyInvites(@Nonnull UUID uuid) {
        HashMap<Integer, Long> userInvites = this.invites.get(uuid);
        if (userInvites == null || userInvites.size() <= 0) {
            return Collections.emptyList();
        }
        List<Map.Entry<Integer, Long>> list = new ArrayList<>(userInvites.entrySet());
        list.sort(Comparator.comparing((v0) -> {
            return v0.getValue();
        }));
        return list;
    }

    public synchronized void purgeInvites(int partyID) {
        this.invites.values().forEach(value -> {
        });
    }

    public synchronized void cleanExpired() {
        MinecraftServer server = MinecraftServer.func_71276_C();
        Iterator<Map.Entry<UUID, HashMap<Integer, Long>>> iterA = this.invites.entrySet().iterator();
        while (iterA.hasNext()) {
            Map.Entry<UUID, HashMap<Integer, Long>> userInvites = iterA.next();
            List<Integer> revoked = new ArrayList<>();
            Iterator<Map.Entry<Integer, Long>> iterB = userInvites.getValue().entrySet().iterator();
            while (iterB.hasNext()) {
                Map.Entry<Integer, Long> entry = iterB.next();
                if (entry.getValue().longValue() < System.currentTimeMillis()) {
                    revoked.add(entry.getKey());
                    iterB.remove();
                }
            }
            EntityPlayerMP player = null;
            Iterator it = server.func_71203_ab().field_72404_b.iterator();
            while (true) {
                if (!it.hasNext()) {
                    break;
                }
                Object o = it.next();
                if (((EntityPlayerMP) o).func_146103_bH().getId().equals(userInvites.getKey())) {
                    player = (EntityPlayerMP) o;
                    break;
                }
            }
            if (player != null && revoked.size() >= 0) {
                int[] revAry = new int[revoked.size()];
                for (int i = 0; i < revoked.size(); i++) {
                    revAry[i] = revoked.get(i).intValue();
                }
                NetInviteSync.sendRevoked(player, revAry);
            }
            if (userInvites.getValue().size() <= 0) {
                iterA.remove();
            }
        }
    }

    public synchronized void reset() {
        this.invites.clear();
    }

    public synchronized NBTTagList writeToNBT(NBTTagList nbt, @Nullable List<UUID> subset) {
        if (subset != null) {
            subset.forEach(uuid -> {
                NBTTagCompound userTag = new NBTTagCompound();
                userTag.func_74778_a("uuid", uuid.toString());
                Map<Integer, Long> userMap = this.invites.get(uuid);
                if (userMap == null) {
                    userMap = Collections.emptyMap();
                }
                NBTTagList invList = new NBTTagList();
                for (Map.Entry<Integer, Long> invEntry : userMap.entrySet()) {
                    NBTTagCompound invTag = new NBTTagCompound();
                    invTag.func_74768_a("partyID", invEntry.getKey().intValue());
                    invTag.func_74772_a("expiry", invEntry.getValue().longValue());
                    invList.func_74742_a(invTag);
                }
                userTag.func_74782_a("invites", invList);
                nbt.func_74742_a(userTag);
            });
        } else {
            for (Map.Entry<UUID, HashMap<Integer, Long>> userMap : this.invites.entrySet()) {
                NBTTagCompound userTag = new NBTTagCompound();
                userTag.func_74778_a("uuid", userMap.getKey().toString());
                NBTTagList invList = new NBTTagList();
                for (Map.Entry<Integer, Long> invEntry : userMap.getValue().entrySet()) {
                    NBTTagCompound invTag = new NBTTagCompound();
                    invTag.func_74768_a("partyID", invEntry.getKey().intValue());
                    invTag.func_74772_a("expiry", invEntry.getValue().longValue());
                    invList.func_74742_a(invTag);
                }
                userTag.func_74782_a("invites", invList);
                nbt.func_74742_a(userTag);
            }
        }
        return nbt;
    }

    public synchronized void readFromNBT(NBTTagList nbt, boolean merge) {
        if (!merge) {
            this.invites.clear();
        }
        for (int i = 0; i < nbt.func_74745_c(); i++) {
            NBTTagCompound userEntry = nbt.func_150305_b(i);
            try {
                UUID uuid = UUID.fromString(userEntry.func_74779_i("uuid"));
                NBTTagList invList = userEntry.func_150295_c("invites", 10);
                HashMap<Integer, Long> map = this.invites.compute(uuid, (key, old) -> {
                    return new HashMap();
                });
                map.clear();
                for (int n = 0; n < invList.func_74745_c(); n++) {
                    NBTTagCompound invEntry = invList.func_150305_b(n);
                    int partyID = invEntry.func_150297_b("partyID", 99) ? invEntry.func_74762_e("partyID") : -1;
                    long timestamp = invEntry.func_150297_b("expiry", 99) ? invEntry.func_74763_f("expiry") : -1L;
                    if (partyID >= 0) {
                        map.put(Integer.valueOf(partyID), Long.valueOf(timestamp));
                    }
                }
            } catch (Exception e) {
            }
        }
    }
}
